BFGraph: CompressedCoverage Class Reference

BFGraph

Public Member Functions | Static Public Attributes
CompressedCoverage Class Reference

## Public Member Functions
| CompressedCoverage (size_t sz=0, bool full=false)
| CompressedCoverage (const CompressedCoverage &o)
CompressedCoverage & | operator= (const CompressedCoverage &o)
| CompressedCoverage (CompressedCoverage &&o)
CompressedCoverage & | operator= (CompressedCoverage &&o)
void | initialize (const size_t sz, const bool full)
void | cover (size_t start, size_t end)
uint8_t | covAt (const size_t index) const
bool | isFull () const
void | setFull ()
vector< pair< int, int > > | splittingVector () const
pair< size_t, size_t > | lowCoverageInfo () const
size_t | size () const
std::string | toString () const

## Static Public Attributes
static const size_t | size_limit = 28
static const size_t | cov_full = 2

The documentation for this class was generated from the following files:

- src/CompressedCoverage.hpp
- src/CompressedCoverage.cpp